### Name: rsf.default
### Title: Random Survival Forest Entry Point
### Aliases: rsf.default rsf randomSurvivalForest
### Keywords: survival tree

### ** Examples

#------------------------------------------------------------
# Example 1:  Veteran's Administration lung cancer trial from
# Kalbfleisch & Prentice.  Randomized trial of two treatment
# regimens for lung cancer.  Minimal argument call.  Print
# results, then plot error rate and importance values.

data(veteran, package = "randomSurvivalForest")
veteran.out <- rsf(Survrsf(time, status)~., data = veteran)
print(veteran.out)
plot(veteran.out)

#------------------------------------------------------------
# Example 2:  Richer argument call (veteran data).
# Forest is saved by setting 'forest' option to true
# (see 'rsf.predict' for more details about prediction).
# Coerce variable 'celltype' as a factor, and karnofsky score
# as an ordered factor to illustrate factor useage in RSF.
# Use random splitting with 'nsplit'.
# Use 'varUsed' option.

data(veteran, package = "randomSurvivalForest")
veteran.f <- as.formula(Survrsf(time, status)~.)
veteran$celltype <- factor(veteran$celltype,
    labels=c("squamous", "smallcell",  "adeno",  "large"))
veteran$karno <- factor(veteran$karno, ordered = TRUE)
ntree <- 200
mtry <- 2
nodesize <- 3
splitrule <- "logrank"
nsplit <- 10
varUsed <- "by.tree"
forest <- TRUE
proximity <- TRUE
do.trace <- 1
veteran2.out <- rsf(veteran.f, veteran, ntree,
       mtry, nodesize, splitrule, nsplit,
       varUsed = varUsed, forest = forest, 
       proximity = proximity, do.trace = do.trace)
print(veteran2.out)
plot.proximity(veteran2.out)

# Take a peek at the forest ...
head(veteran2.out$forest$nativeArray)

# Average number of times a variable was split on.
apply(veteran2.out$varUsed,2,mean)

# Partial plot of top variable.
plot.variable(veteran2.out, partial = TRUE, npred=1)

## Not run: 
##D #------------------------------------------------------------
##D # Example 3:  Veteran data (again).
##D # Consider Karnofsky performance score. Compare to Kaplan-Meier.
##D # Assumes "survival" library is loaded.
##D 
##D if (library("survival", logical.return = TRUE))
##D {
##D         data(veteran, package = "randomSurvivalForest")
##D         veteran3.out <- rsf(Survrsf(time, status)~karno,
##D                        veteran,
##D                        ntree = 1000)
##D         plot.ensemble(veteran3.out)
##D         par(mfrow = c(1,1))
##D         plot(survfit(Surv(time, status)~karno, data = veteran))
##D }
##D 
##D #------------------------------------------------------------
##D # Example 4:  Primary biliary cirrhosis (PBC) of the liver.
##D # Data found in Appendix D.1 of Fleming and Harrington, Counting
##D # Processes and Survival Analysis, Wiley, 1991 (modified so
##D # that age is in days and sex and stage variables are not
##D # missing for observations 313-418).  
##D 
##D data(pbc, package = "randomSurvivalForest") 
##D pbc.out <- rsf(Survrsf(days,status)~., pbc, ntree = 1000)
##D print(pbc.out)
##D 
##D #------------------------------------------------------------
##D # Example 5:  Same as Example 4, but with imputation for
##D # missing values.
##D 
##D data(pbc, package = "randomSurvivalForest") 
##D pbc2.out <- rsf(Survrsf(days,status)~., pbc, ntree = 1000,
##D                 na.action="na.impute")
##D # summary of analysis
##D print(pbc2.out)
##D # Combine original data + imputed data.
##D pbc.imputed.data <- cbind(status=pbc2.out$cens, days=pbc2.out$time,
##D                           pbc2.out$predictors)
##D pbc.imputed.data[pbc2.out$imputedIndv,] <- pbc2.out$imputedData
##D tail(pbc)
##D tail(pbc.imputed.data)
##D # Iterate the missing data algorithm.
##D # Use logrank random splitting (with nsplit=5) to increase speed.
##D # Use trace to track algorithm in detail.
##D # Note that a side effect of iterating is that the original data
##D # are replaced by imputed values.
##D pbc3.out <- rsf(Survrsf(days,status)~., pbc, ntree = 1000, nsplit=5, 
##D          na.action="na.impute", nimpute=3, do.trace = TRUE)
##D pbc.iterate.imputed.data <- cbind(status=pbc3.out$cens,
##D          days=pbc3.out$time, pbc3.out$predictors)
##D 
##D #------------------------------------------------------------
##D # Example 6:  Compare Cox regression to RSF (PBC data).
##D # Compute OOB estimate of Harrell's concordance 
##D # index for Cox regression using B = 100 bootstrap draws.
##D # Assumes "Hmisc" and "survival" libraries are loaded. 
##D 
##D if (library("survival", logical.return = TRUE) 
##D     & library("Hmisc", logical.return = TRUE))
##D {
##D   data(pbc, package = "randomSurvivalForest")
##D   pbc3.out <- rsf(Survrsf(days,status)~., pbc, mtry = 2, ntree = 1000)
##D   B <- 100 
##D   cox.err <- rep(NA, B) 
##D   cox.f <- as.formula(Surv(days,status)~.)  
##D   pbc.data <- pbc[apply(is.na(pbc), 1, sum) == 0,] ##remove NA's 
##D   cat("Out-of-bag Cox Analysis ...", "\n")
##D   for (b in 1:B) {
##D     cat("Cox bootstrap:", b, "\n") 
##D     bag.sample <- sample(1:nrow(pbc.data),
##D                          nrow(pbc.data),
##D                          replace = TRUE) 
##D     oob.sample <- setdiff(1:nrow(pbc.data), bag.sample)
##D     train <- pbc.data[bag.sample,]
##D     test <- pbc.data[oob.sample,]
##D     cox.out <- coxph(cox.f, train)
##D     cox.out <- tryCatch({coxph(cox.f, train)}, error=function(ex){NULL})
##D     if (is.list(cox.out)) {
##D       cox.predict <- predict(cox.out, test)
##D       cox.err[b] <- rcorr.cens(cox.predict, 
##D               Surv(pbc.data$days[oob.sample],
##D               pbc.data$status[oob.sample]))[1]
##D     }
##D   }
##D   cat("Error rates:", "\n")
##D   cat("Random Survival Forests:", pbc3.out$err.rate[pbc3.out$ntree], "\n")
##D   cat("         Cox Regression:", mean(cox.err, na.rm = TRUE), "\n")
##D }
## End(Not run)



